package com.dkl.large.mapper;

import com.dkl.large.domain.DklClip;

import java.util.List;

/**
 * 视频Mapper接口
 *
 * @author Dkl
 * @date 2025-11-03
 */
public interface DklClipMapper
{
    /**
     * 查询视频
     *
     * @param id 视频主键
     * @return 视频
     */
    public DklClip selectDklClipById(Long id);

    /**
     * 查询视频列表
     *
     * @param dklClip 视频
     * @return 视频集合
     */
    public List<DklClip> selectDklClipList(DklClip dklClip);

    /**
     * 新增视频
     *
     * @param dklClip 视频
     * @return 结果
     */
    public int insertDklClip(DklClip dklClip);

    /**
     * 修改视频
     *
     * @param dklClip 视频
     * @return 结果
     */
    public int updateDklClip(DklClip dklClip);

    /**
     * 删除视频
     *
     * @param id 视频主键
     * @return 结果
     */
    public int deleteDklClipById(Long id);

    /**
     * 批量删除视频
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDklClipByIds(Long[] ids);
}
